@@ -172,7 +172,7 @@ foreach my $index (sort @indices) {
     if( $CFG{close} && $CFG{'close-days'} < $days_old ) {
         my $status = es_request('_status',{index=>$index});
         if( defined $status ) {
-            if( $status->{_shards}{total} > 0 ) {
+            if( defined $status->{_shards} && exists $status->{_shards}{total} && $status->{_shards}{total} > 0 ) {
                 # retrieve aliases
                 my $ars = es_request('_alias', {index=>$index});
                 foreach my $alias ( keys %{ $ars->{$index}{aliases} } ) {
@@ -216,7 +216,7 @@ es-daily-index-maintenance.pl - Run to prune old indexes and optimize existing
 
 =head1 VERSION
 
-version 3.4
+version 3.5
 
 =head1 SYNOPSIS
 
@@ -266,7 +266,7 @@ From CLI::Helpers:
 
     --data-file         Path to a file to write lines tagged with 'data => 1'
     --color             Boolean, enable/disable color, default use git settings
-    --verbose           Incremental, increase verbosity
+    --verbose           Incremental, increase verbosity (Alias is -v)
     --debug             Show developer output
     --quiet             Show no output (for cron)
 
