@@ -410,18 +410,18 @@ sub show_fields {
 sub show_bases {
     output({color=>'cyan'}, 'Bases available for search:' );
     my $bases = {};
-    foreach my $index (sort keys \%indices) {
+    foreach my $index (sort keys %indices) {
         foreach my $base (split('-', $index)) {
             $bases->{$base} = '';
         }
     }
-    foreach my $base (sort keys $bases) {
+    foreach my $base (sort keys %$bases) {
         output(" - $base");
     }
 
     output({color=>"yellow"},
         sprintf("# Bases: %d from a combined %d indices.\n",
-            scalar(keys $bases),
+            scalar(keys %$bases),
             scalar(keys %indices),
         )
     );
@@ -473,7 +473,7 @@ sub format_search_string {
                 }
             }
             if($term =~ /_ip$/ ) {
-                if($match =~ m|^\d{1,3}(\.\d{1,3}){1,3}(/\d+)?$|) {
+                if($match =~ m|^\d{1,3}(\.\d{1,3}){1,3}(/\d+)$|) {
                     my $cidr = Net::CIDR::Lite->new();
                     $cidr->add($match);
                     my @range = split /-/, ($cidr->list_range)[0];
@@ -498,7 +498,7 @@ es-search.pl - Provides a CLI for quick searches of data in ElasticSearch daily
 
 =head1 VERSION
 
-version 3.4
+version 3.5
 
 =head1 SYNOPSIS
 
@@ -554,7 +554,7 @@ From CLI::Helpers:
 
     --data-file         Path to a file to write lines tagged with 'data => 1'
     --color             Boolean, enable/disable color, default use git settings
-    --verbose           Incremental, increase verbosity
+    --verbose           Incremental, increase verbosity (Alias is -v)
     --debug             Show developer output
     --quiet             Show no output (for cron)
 
